@@ -1,6 +1,7 @@
 """Main agent that coordinates all components"""
 
 import time
+from datetime import datetime
 from pathlib import Path
 from typing import Optional, Dict, Any
 from rich.console import Console
@@ -27,9 +28,9 @@ class CacheAgent:
         self.kb = kb if kb is not None else KnowledgeBase(db_path)
         self.processor = LogProcessor(self.kb)
         self.detector = EnhancedSuccessDetector()  # Using enhanced detector for better stack awareness
-        self.injector = ContextInjector(self.kb)
-        self.watcher = LogWatcher(self.processor)
-        self.realtime_updater = RealtimeContextUpdater(self.kb, self.injector)
+        self.injector = None  # Will be initialized based on mode
+        self.watcher = None  # Will be initialized based on mode
+        self.realtime_updater = None  # Will be initialized based on mode
         self.config_watcher = HotReloadWatcher()
 
         self.processor.detector = self.detector
@@ -54,16 +55,36 @@ class CacheAgent:
         if not self.first_run_check_done:
             self._check_first_run()
 
-        console.print("[blue]Processing existing logs...[/blue]")
-        self.process_existing_logs()
-
         if watch:
+            # For monitoring mode, create watcher in silent mode
+            self.watcher = LogWatcher(self.processor, silent=True)
+            self.injector = ContextInjector(self.kb, silent=True)
+            self.realtime_updater = RealtimeContextUpdater(self.kb, self.injector, silent=True)
+            self.processor.silent_mode = True
+            self.watcher.process_existing_logs()
             console.print("[blue]Starting real-time monitoring...[/blue]")
             self.start_monitoring()
+        else:
+            # Full processing for non-watch mode - verbose
+            self.watcher = LogWatcher(self.processor, silent=False)
+            self.injector = ContextInjector(self.kb, silent=False)
+            self.realtime_updater = RealtimeContextUpdater(self.kb, self.injector)
+            console.print("[blue]Processing existing logs...[/blue]")
+            self.process_existing_logs()
 
     def process_existing_logs(self):
         """Process all existing log files with progress tracking"""
         try:
+            # First, count how many logs we have
+            projects_dir = Path.home() / '.claude' / 'projects'
+            log_count = len(list(projects_dir.glob('**/*.jsonl'))) if projects_dir.exists() else 0
+
+            if log_count == 0:
+                console.print("[yellow]No Claude Code conversation logs found yet.[/yellow]")
+                console.print("[dim]Logs are created when you use Claude Code in Cursor/VS Code[/dim]")
+                console.print("[dim]They are stored in: ~/.claude/projects/[/dim]\n")
+                return
+
             with Progress(
                 SpinnerColumn(),
                 TextColumn("[progress.description]{task.description}"),
@@ -74,7 +95,7 @@ class CacheAgent:
             ) as progress:
 
                 # Process existing logs
-                task = progress.add_task("[cyan]Processing existing logs...", total=100)
+                task = progress.add_task(f"[cyan]Processing {log_count} log files...", total=100)
                 self.watcher.process_existing_logs()
                 progress.update(task, advance=30)
 
@@ -104,6 +125,9 @@ class CacheAgent:
 
     def start_monitoring(self):
         """Start real-time log monitoring with context updates"""
+        # Enable silent mode for log processor to suppress messages
+        self.processor.silent_mode = True
+
         # Start real-time context updates
         self.realtime_updater.start()
 
@@ -114,10 +138,14 @@ class CacheAgent:
         observer = self.watcher.start()
 
         try:
-            with Live(self.generate_status_table(), refresh_per_second=1) as live:
+            # Clear console for clean display
+            console.clear()
+
+            with Live(self.generate_status_table(), refresh_per_second=0.033, auto_refresh=False) as live:
                 while True:
-                    time.sleep(1)
+                    time.sleep(30)
                     live.update(self.generate_status_table())
+                    live.refresh()
 
         except KeyboardInterrupt:
             console.print("\n[yellow]Stopping monitoring...[/yellow]")
@@ -356,21 +384,61 @@ class CacheAgent:
         except:
             return None
 
+    def _get_recent_pattern_count(self) -> int:
+        """Get count of patterns from last 24 hours"""
+        import sqlite3
+        from datetime import datetime, timedelta
+        try:
+            conn = sqlite3.connect(self.kb.db_path)
+            cursor = conn.cursor()
+            yesterday = (datetime.now() - timedelta(days=1)).isoformat()
+            cursor.execute("""
+                SELECT COUNT(*)
+                FROM success_patterns
+                WHERE created_at > ?
+            """, (yesterday,))
+            result = cursor.fetchone()
+            conn.close()
+            return result[0] if result else 0
+        except:
+            return 0
+
     def generate_status_table(self):
         """Generate a status table for live display"""
         stats = self.kb.get_statistics()
+        patterns = stats.get('total_patterns', 0)
+        projects = stats.get('projects', 0)
 
-        table = Table(title="Claude Cache - Live Status", show_header=True)
-        table.add_column("Metric", style="cyan")
-        table.add_column("Value", style="green")
+        # Get most active project
+        most_active = self._get_most_active_project()
 
-        table.add_row("Patterns", str(stats.get('total_patterns', 0)))
-        table.add_row("Projects", str(stats.get('projects', 0)))
-        table.add_row("Requests", str(stats.get('total_requests', 0)))
-        table.add_row("Status", "[green]● Monitoring[/green]")
+        # Get recent activity count (patterns from last 24h)
+        recent_patterns = self._get_recent_pattern_count()
+
+        table = Table(title="🧠 Claude Cache - Live Monitoring", show_header=True, border_style="blue")
+        table.add_column("Metric", style="cyan", width=22)
+        table.add_column("Value", style="green", width=20)
+        table.add_column("Status", style="yellow", width=35)
+
+        table.add_row("Patterns Learned", str(patterns), self._get_pattern_status(patterns))
+        table.add_row("Projects Tracked", str(projects), f"Monitoring ~/.claude/projects/")
+        table.add_row("Most Active", most_active or "None yet", "Current session leader")
+        table.add_row("Recent Activity", f"{recent_patterns} today", "New patterns detected")
+        table.add_row("Status", "[green]● Watching[/green]", f"Updated {datetime.now().strftime('%H:%M:%S')}")
 
         return table
 
+    def _get_pattern_status(self, count: int) -> str:
+        """Get encouraging status message based on pattern count"""
+        if count == 0:
+            return "Keep using Claude Code!"
+        elif count < 10:
+            return "Building knowledge... 🌱"
+        elif count < 50:
+            return "Growing nicely! 🌳"
+        else:
+            return "Rich knowledge base! 🏆"
+
     def query_patterns(self, query: str, project: Optional[str] = None):
         """Query all indexed content using unified search"""
         # Use unified search that includes both patterns and documentation
@@ -463,7 +531,7 @@ class CacheAgent:
             self.first_run_check_done = True
             return
 
-        # Check if knowledge base is empty
+        # Check if knowledge base is completely empty
         stats = self.kb.get_statistics()
         doc_stats = self._get_documentation_statistics()
 
@@ -472,9 +540,9 @@ class CacheAgent:
         has_requests = stats.get('total_requests', 0) > 0
         has_docs = doc_stats['total_docs'] > 0
 
-        # Skip first-run if we have any existing data
+        # If we have any data, don't show first-run prompt
+        # But still allow log processing to continue
         if has_patterns or has_requests or has_docs:
-            console.print(f"[dim]Found existing data: {doc_stats['total_docs']} docs, {stats.get('total_patterns', 0)} patterns[/dim]")
             # Create flag file to skip future first-run checks
             first_run_flag.touch()
             self.first_run_check_done = True
@@ -762,7 +830,7 @@ class CacheAgent:
     ║  | |__ / ___ \\| |___|  _  | |___          ║
     ║   \\___/_/   \\_\\\\____|_| |_|_____|         ║
     ║                                           ║
-    ║                v0.5.0                     ║
+    ║                v0.7.0                     ║
     ╚═══════════════════════════════════════════╝
         """
 
